@@ -72,7 +72,7 @@ def _cut_legend(legend):
 
     # Crop Image
     area = im.crop(box)
-    area.show()
+    #area.show()
 
     # Save Image
     area.save(legend, "PNG")
